pub async fn reflect_db_state(client: &PgClient) -> Result<DbState, Error>Expand description
A large wrapper function that calls all the other reflection functions.
All reflection functions narrow their scope to the single database client is configured to connect to. This includes all catalog tables that point to a database.
Any object created in the pg_temp namespace or any pg_toast namespaces are also ignored.