pub struct PgAmop {
pub amopfamily: SmolStr,
pub amoplefttype: SmolStr,
pub amoprighttype: SmolStr,
pub amopstrategy: u16,
pub amoppurpose: PgAmopAmoppurpose,
pub amopopr: SmolStr,
pub amopmethod: SmolStr,
pub amopsortfamily: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_amop
Fields
amopfamily: SmolStroid (references pg_opfamily.oid) The operator family this entry is for
amoplefttype: SmolStroid (references pg_type.oid) Left-hand input data type of operator
amoprighttype: SmolStroid (references pg_type.oid) Right-hand input data type of operator
amopstrategy: u16int2 Operator strategy number
amoppurpose: PgAmopAmoppurposechar Operator purpose, either s for search or o for ordering
amopopr: SmolStroid (references pg_operator.oid) OID of the operator
amopmethod: SmolStroid (references pg_am.oid) Index access method operator family is for
amopsortfamily: Option<SmolStr>oid (references pg_opfamily.oid) The B-tree operator family this entry sorts according to, if an ordering operator; zero if a search operator