pub struct PgCast {
pub castsource: SmolStr,
pub casttarget: SmolStr,
pub castfunc: Option<SmolStr>,
pub castcontext: PgCastCastcontext,
pub castmethod: PgCastCastmethod,
pub description: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_cast
Fields
castsource: SmolStroid (references pg_type.oid) OID of the source data type
casttarget: SmolStroid (references pg_type.oid) OID of the target data type
castfunc: Option<SmolStr>oid (references pg_proc.oid) The OID of the function to use to perform this cast. Zero is stored if the cast method doesn’t require a function.
castcontext: PgCastCastcontextchar Indicates what contexts the cast can be invoked in. e means only as an explicit cast (using CAST or :: syntax). a means implicitly in assignment to a target column, as well as explicitly. i means implicitly in expressions, as well as the other cases.
castmethod: PgCastCastmethodchar Indicates how the cast is performed. f means that the function specified in the castfunc field is used. i means that the input/output functions are used. b means that the types are binary-coercible, thus no conversion is required.
description: Option<SmolStr>text The comment from pg_description