pub struct PgCollation {
pub oid: SmolStr,
pub collname: SmolStr,
pub collnamespace: SmolStr,
pub collowner: SmolStr,
pub collprovider: PgCollationCollprovider,
pub collisdeterministic: bool,
pub collencoding: Option<SmolStr>,
pub collcollate: Option<SmolStr>,
pub collctype: Option<SmolStr>,
pub colllocale: Option<SmolStr>,
pub collicurules: Option<SmolStr>,
pub description: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_collation
Fields
oid: SmolStroid Row identifier
collname: SmolStrname Collation name (unique per namespace and encoding)
collnamespace: SmolStroid (references pg_namespace.oid) The OID of the namespace that contains this collation
collowner: SmolStroid (references pg_authid.oid) Owner of the collation
collprovider: PgCollationCollproviderchar Provider of the collation: d = database default, b = builtin, c = libc, i = icu
collisdeterministic: boolbool Is the collation deterministic?
collencoding: Option<SmolStr>int4 Encoding in which the collation is applicable, or -1 if it works for any encoding
collcollate: Option<SmolStr>text LC_COLLATE for this collation object. If the provider is not libc, collcollate is NULL and colllocale is used instead.
collctype: Option<SmolStr>text LC_CTYPE for this collation object. If the provider is not libc, collctype is NULL and colllocale is used instead.
colllocale: Option<SmolStr>text Collation provider locale name for this collation object. If the provider is libc, colllocale is NULL; collcollate and collctype are used instead.
collicurules: Option<SmolStr>text ICU collation rules for this collation object
description: Option<SmolStr>text The comment from pg_description