pub struct PgDatabase {Show 15 fields
pub datname: SmolStr,
pub datdba: SmolStr,
pub encoding: SmolStr,
pub datlocprovider: PgDatabaseDatlocprovider,
pub datistemplate: bool,
pub datallowconn: bool,
pub datconnlimit: Option<u32>,
pub datcollate: Option<SmolStr>,
pub datctype: Option<SmolStr>,
pub datlocale: Option<SmolStr>,
pub daticurules: Option<SmolStr>,
pub datacl: Option<Vec<AclItem<DbAclPrivilege>>>,
pub description: Option<SmolStr>,
pub seclabel: Option<SmolStr>,
pub seclabel_provider: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_database
Fields
datname: SmolStrname Database name
datdba: SmolStroid (references pg_authid.oid) Owner of the database, usually the user who created it
encoding: SmolStrint4 Character encoding for this database (pg_encoding_to_char() can translate this number to the encoding name)
datlocprovider: PgDatabaseDatlocproviderchar Locale provider for this database: b = builtin, c = libc, i = icu
datistemplate: boolbool If true, then this database can be cloned by any user with CREATEDB privileges; if false, then only superusers or the owner of the database can clone it.
datallowconn: boolbool If false then no one can connect to this database. This is used to protect the template0 database from being altered.
datconnlimit: Option<u32>int4 Sets maximum number of concurrent connections that can be made to this database. -1 means no limit, -2 indicates the database is invalid.
datcollate: Option<SmolStr>text LC_COLLATE for this database
datctype: Option<SmolStr>text LC_CTYPE for this database
datlocale: Option<SmolStr>text Collation provider locale name for this database. If the provider is libc, datlocale is NULL; datcollate and datctype are used instead.
daticurules: Option<SmolStr>text ICU collation rules for this database
datacl: Option<Vec<AclItem<DbAclPrivilege>>>aclitem[] Access privileges; see Section 5.8 for details
description: Option<SmolStr>text The comment from pg_shdescription
seclabel: Option<SmolStr>text The seclabel from pg_shseclabel
seclabel_provider: Option<SmolStr>text The provider from pg_shseclabel