pub struct PgForeignDataWrapper {
pub fdwname: SmolStr,
pub fdwowner: SmolStr,
pub fdwhandler: Option<SmolStr>,
pub fdwvalidator: Option<SmolStr>,
pub fdwacl: Option<Vec<AclItem<ForeignDataWrapperAclPrivilege>>>,
pub fdwoptions: Option<Vec<SmolStr>>,
pub description: Option<SmolStr>,
pub initprivs: Option<Vec<AclItem<ForeignDataWrapperAclPrivilege>>>,
pub initprivs_type: Option<PgForeignDataWrapperInitprivsType>,
}Expand description
The DDL-only contents of pg_foreign_data_wrapper
Fields
fdwname: SmolStrname Name of the foreign-data wrapper
fdwowner: SmolStroid (references pg_authid.oid) Owner of the foreign-data wrapper
fdwhandler: Option<SmolStr>oid (references pg_proc.oid) References a handler function that is responsible for supplying execution routines for the foreign-data wrapper. Zero if no handler is provided
fdwvalidator: Option<SmolStr>oid (references pg_proc.oid) References a validator function that is responsible for checking the validity of the options given to the foreign-data wrapper, as well as options for foreign servers and user mappings using the foreign-data wrapper. Zero if no validator is provided
fdwacl: Option<Vec<AclItem<ForeignDataWrapperAclPrivilege>>>aclitem[] Access privileges; see Section 5.8 for details
fdwoptions: Option<Vec<SmolStr>>text[] Foreign-data wrapper specific options, as “keyword=value” strings
description: Option<SmolStr>text The comment from pg_description
initprivs: Option<Vec<AclItem<ForeignDataWrapperAclPrivilege>>>aclitem[] The initial access privileges from pg_init_privs.
initprivs_type: Option<PgForeignDataWrapperInitprivsType>char A code defining the type of initial privilege of this object from pg_init_privs. ‘i’ if set by initdb, ‘e’ if set by CREATE EXTENSION.