PgInherits

Struct PgInherits 

pub struct PgInherits {
    pub inhrelid: SmolStr,
    pub inhparent: SmolStr,
    pub inhseqno: u32,
}
The DDL-only contents of pg_inherits

Fields

inhrelid: SmolStr

oid (references pg_class.oid) The OID of the child table or index

inhparent: SmolStr

oid (references pg_class.oid) The OID of the parent table or index

inhseqno: u32

int4 If there is more than one direct parent for a child table (multiple inheritance), this number tells the order in which the inherited columns are to be arranged. The count starts at 1. Indexes cannot have multiple inheritance, since they can only inherit when using declarative partitioning.