pub struct PgLanguage {Show 13 fields
pub lanname: SmolStr,
pub lanowner: SmolStr,
pub lanispl: bool,
pub lanpltrusted: bool,
pub lanplcallfoid: Option<SmolStr>,
pub laninline: Option<SmolStr>,
pub lanvalidator: Option<SmolStr>,
pub lanacl: Option<Vec<AclItem<LanguageAclPrivilege>>>,
pub description: Option<SmolStr>,
pub seclabel: Option<SmolStr>,
pub seclabel_provider: Option<SmolStr>,
pub initprivs: Option<Vec<AclItem<LanguageAclPrivilege>>>,
pub initprivs_type: Option<PgLanguageInitprivsType>,
}Expand description
The DDL-only contents of pg_language
Fields
lanname: SmolStrname Name of the language
lanowner: SmolStroid (references pg_authid.oid) Owner of the language
lanispl: boolbool This is false for internal languages (such as SQL) and true for user-defined languages. Currently, pg_dump still uses this to determine which languages need to be dumped, but this might be replaced by a different mechanism in the future.
lanpltrusted: boolbool True if this is a trusted language, which means that it is believed not to grant access to anything outside the normal SQL execution environment. Only superusers can create functions in untrusted languages.
lanplcallfoid: Option<SmolStr>oid (references pg_proc.oid) For noninternal languages this references the language handler, which is a special function that is responsible for executing all functions that are written in the particular language. Zero for internal languages.
laninline: Option<SmolStr>oid (references pg_proc.oid) This references a function that is responsible for executing “inline” anonymous code blocks (DO blocks). Zero if inline blocks are not supported.
lanvalidator: Option<SmolStr>oid (references pg_proc.oid) This references a language validator function that is responsible for checking the syntax and validity of new functions when they are created. Zero if no validator is provided.
lanacl: Option<Vec<AclItem<LanguageAclPrivilege>>>aclitem[] Access privileges; see Section 5.8 for details
description: Option<SmolStr>text The comment from pg_description
seclabel: Option<SmolStr>text The seclabel from pg_seclabel
seclabel_provider: Option<SmolStr>text The provider from pg_seclabel
initprivs: Option<Vec<AclItem<LanguageAclPrivilege>>>aclitem[] The initial access privileges from pg_init_privs.
initprivs_type: Option<PgLanguageInitprivsType>char A code defining the type of initial privilege of this object from pg_init_privs. ‘i’ if set by initdb, ‘e’ if set by CREATE EXTENSION.