pub struct PgPolicy {
pub polname: SmolStr,
pub polrelid: SmolStr,
pub polcmd: PgPolicyPolcmd,
pub polpermissive: bool,
pub polroles: Vec<Option<SmolStr>>,
pub polqual: Option<SmolStr>,
pub polwithcheck: Option<SmolStr>,
pub description: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_policy
Fields
polname: SmolStrname The name of the policy
polrelid: SmolStroid (references pg_class.oid) The table to which the policy applies
polcmd: PgPolicyPolcmdchar The command type to which the policy is applied: r for SELECT, a for INSERT, w for UPDATE, d for DELETE, or * for all
polpermissive: boolbool Is the policy permissive or restrictive?
polroles: Vec<Option<SmolStr>>oid[] (references pg_authid.oid) The roles to which the policy is applied; zero means PUBLIC (and normally appears alone in the array)
polqual: Option<SmolStr>pg_node_tree The expression tree to be added to the security barrier qualifications for queries that use the table
polwithcheck: Option<SmolStr>pg_node_tree The expression tree to be added to the WITH CHECK qualifications for queries that attempt to add rows to the table
description: Option<SmolStr>text The comment from pg_description