pub struct PgPublication {
pub pubname: SmolStr,
pub pubowner: SmolStr,
pub puballtables: bool,
pub pubinsert: bool,
pub pubupdate: bool,
pub pubdelete: bool,
pub pubtruncate: bool,
pub pubviaroot: bool,
pub description: Option<SmolStr>,
pub seclabel: Option<SmolStr>,
pub seclabel_provider: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_publication
Fields
pubname: SmolStrname Name of the publication
pubowner: SmolStroid (references pg_authid.oid) Owner of the publication
puballtables: boolbool If true, this publication automatically includes all tables in the database, including any that will be created in the future.
pubinsert: boolbool If true, INSERT operations are replicated for tables in the publication.
pubupdate: boolbool If true, UPDATE operations are replicated for tables in the publication.
pubdelete: boolbool If true, DELETE operations are replicated for tables in the publication.
pubtruncate: boolbool If true, TRUNCATE operations are replicated for tables in the publication.
pubviaroot: boolbool If true, operations on a leaf partition are replicated using the identity and schema of its topmost partitioned ancestor mentioned in the publication instead of its own.
description: Option<SmolStr>text The comment from pg_description
seclabel: Option<SmolStr>text The seclabel from pg_seclabel
seclabel_provider: Option<SmolStr>text The provider from pg_seclabel