pub struct PgPublicationRel {
pub prpubid: SmolStr,
pub prrelid: SmolStr,
pub prqual: Option<SmolStr>,
pub prattrs: Option<Vec<u16>>,
}Expand description
The DDL-only contents of pg_publication_rel
Fields
prpubid: SmolStroid (references pg_publication.oid) Reference to publication
prrelid: SmolStroid (references pg_class.oid) Reference to relation
prqual: Option<SmolStr>pg_node_tree Expression tree (in nodeToString() representation) for the relation’s publication qualifying condition. Null if there is no publication qualifying condition.
prattrs: Option<Vec<u16>>int2vector (references pg_attribute.attnum) This is an array of values that indicates which table columns are part of the publication. For example, a value of 1 3 would mean that the first and the third table columns are published. A null value indicates that all columns are published.