pub struct PgRange {
pub rngtypid: SmolStr,
pub rngsubtype: SmolStr,
pub rngmultitypid: SmolStr,
pub rngcollation: Option<SmolStr>,
pub rngsubopc: SmolStr,
pub rngcanonical: Option<SmolStr>,
pub rngsubdiff: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_range
Fields
rngtypid: SmolStroid (references pg_type.oid) OID of the range type
rngsubtype: SmolStroid (references pg_type.oid) OID of the element type (subtype) of this range type
rngmultitypid: SmolStroid (references pg_type.oid) OID of the multirange type for this range type
rngcollation: Option<SmolStr>oid (references pg_collation.oid) OID of the collation used for range comparisons, or zero if none
rngsubopc: SmolStroid (references pg_opclass.oid) OID of the subtype’s operator class used for range comparisons
rngcanonical: Option<SmolStr>regproc (references pg_proc.oid) OID of the function to convert a range value into canonical form, or zero if none
rngsubdiff: Option<SmolStr>regproc (references pg_proc.oid) OID of the function to return the difference between two element values as double precision, or zero if none