PgRoles

Struct PgRoles 

pub struct PgRoles {
Show 14 fields pub rolname: SmolStr, pub rolsuper: bool, pub rolinherit: bool, pub rolcreaterole: bool, pub rolcreatedb: bool, pub rolcanlogin: bool, pub rolreplication: bool, pub rolconnlimit: Option<u32>, pub rolvaliduntil: Option<DateTime<FixedOffset>>, pub rolbypassrls: bool, pub rolconfig: Option<Vec<SmolStr>>, pub description: Option<SmolStr>, pub seclabel: Option<SmolStr>, pub seclabel_provider: Option<SmolStr>,
}
The DDL-only contents of pg_roles

Fields

rolname: SmolStr

name Role name

rolsuper: bool

bool Role has superuser privileges

rolinherit: bool

bool Role automatically inherits privileges of roles it is a member of

rolcreaterole: bool

bool Role can create more roles

rolcreatedb: bool

bool Role can create databases

rolcanlogin: bool

bool Role can log in. That is, this role can be given as the initial session authorization identifier

rolreplication: bool

bool Role is a replication role. A replication role can initiate replication connections and create and drop replication slots.

rolconnlimit: Option<u32>

int4 For roles that can log in, this sets maximum number of concurrent connections this role can make. -1 means no limit.

rolvaliduntil: Option<DateTime<FixedOffset>>

timestamptz Password expiry time (only used for password authentication); null if no expiration

rolbypassrls: bool

bool Role bypasses every row-level security policy, see Section 5.9 for more information.

rolconfig: Option<Vec<SmolStr>>

text[] Role-specific defaults for run-time configuration variables

description: Option<SmolStr>

text The comment from pg_shdescription

seclabel: Option<SmolStr>

text The seclabel from pg_shseclabel

seclabel_provider: Option<SmolStr>

text The provider from pg_shseclabel