pub struct PgTransform {
pub trftype: SmolStr,
pub trflang: SmolStr,
pub trffromsql: Option<SmolStr>,
pub trftosql: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_transform
Fields
trftype: SmolStroid (references pg_type.oid) OID of the data type this transform is for
trflang: SmolStroid (references pg_language.oid) OID of the language this transform is for
trffromsql: Option<SmolStr>regproc (references pg_proc.oid) The OID of the function to use when converting the data type for input to the procedural language (e.g., function parameters). Zero is stored if the default behavior should be used.
trftosql: Option<SmolStr>regproc (references pg_proc.oid) The OID of the function to use when converting output from the procedural language (e.g., return values) to the data type. Zero is stored if the default behavior should be used.