pub struct PgUserMappings {
pub srvname: SmolStr,
pub umuser: Option<SmolStr>,
pub usename: SmolStr,
pub umoptions: Option<Vec<SmolStr>>,
}Expand description
The DDL-only contents of pg_user_mappings
Fields
srvname: SmolStrname (references pg_foreign_server.srvname) Name of the foreign server
umuser: Option<SmolStr>oid (references pg_authid.oid) OID of the local role being mapped, or zero if the user mapping is public
usename: SmolStrname Name of the local user to be mapped
umoptions: Option<Vec<SmolStr>>text[] User mapping specific options, as “keyword=value” strings