pub struct DbState {Show 52 fields
pub pg_aggregate: Vec<PgAggregate>,
pub pg_am: HashSet<PgAm>,
pub pg_amop: Vec<PgAmop>,
pub pg_amproc: Vec<PgAmproc>,
pub pg_attrdef: Vec<PgAttrdef>,
pub pg_attribute: Vec<PgAttribute>,
pub pg_roles: HashSet<PgRoles>,
pub pg_auth_members: Vec<PgAuthMembers>,
pub pg_cast: Vec<PgCast>,
pub pg_class: HashSet<PgClass>,
pub pg_collation: Vec<PgCollation>,
pub pg_constraint: Vec<PgConstraint>,
pub pg_conversion: Vec<PgConversion>,
pub pg_database: PgDatabase,
pub pg_db_role_setting: Vec<PgDbRoleSetting>,
pub pg_default_acl: Vec<PgDefaultAcl>,
pub pg_enum: HashSet<PgEnum>,
pub pg_event_trigger: Vec<PgEventTrigger>,
pub pg_extension: Vec<PgExtension>,
pub pg_foreign_data_wrapper: Vec<PgForeignDataWrapper>,
pub pg_foreign_server: Vec<PgForeignServer>,
pub pg_foreign_table: Vec<PgForeignTable>,
pub pg_index: Vec<PgIndex>,
pub pg_inherits: Vec<PgInherits>,
pub pg_language: HashSet<PgLanguage>,
pub pg_namespace: HashSet<PgNamespace>,
pub pg_opclass: Vec<PgOpclass>,
pub pg_operator: HashSet<PgOperator>,
pub pg_opfamily: Vec<PgOpfamily>,
pub pg_parameter_acl: Vec<PgParameterAcl>,
pub pg_partitioned_table: Vec<PgPartitionedTable>,
pub pg_policy: Vec<PgPolicy>,
pub pg_proc: HashSet<PgProc>,
pub pg_publication: HashSet<PgPublication>,
pub pg_publication_namespace: Vec<PgPublicationNamespace>,
pub pg_publication_rel: Vec<PgPublicationRel>,
pub pg_range: Vec<PgRange>,
pub pg_rules: Vec<PgRules>,
pub pg_views: Vec<PgViews>,
pub pg_matviews: Vec<PgMatviews>,
pub pg_sequence: Vec<PgSequence>,
pub pg_statistic_ext: Vec<PgStatisticExt>,
pub pg_subscription: Vec<PgSubscription>,
pub pg_transform: Vec<PgTransform>,
pub pg_trigger: Vec<PgTrigger>,
pub pg_ts_config: HashSet<PgTsConfig>,
pub pg_ts_config_map: Vec<PgTsConfigMap>,
pub pg_ts_dict: HashSet<PgTsDict>,
pub pg_ts_parser: Vec<PgTsParser>,
pub pg_ts_template: Vec<PgTsTemplate>,
pub pg_type: HashSet<PgType>,
pub pg_user_mappings: Vec<PgUserMappings>,
}Expand description
A large wrapper struct that holds the results of all the other reflections.
Only includes information for the single database, which is why pg_database isn’t a collection.
Objects that are “cluster shared” such as roles are those for the entire cluster.
Fields
pg_aggregate: Vec<PgAggregate>pg_am: HashSet<PgAm>pg_amop: Vec<PgAmop>pg_amproc: Vec<PgAmproc>pg_attrdef: Vec<PgAttrdef>pg_attribute: Vec<PgAttribute>pg_roles: HashSet<PgRoles>pg_auth_members: Vec<PgAuthMembers>pg_cast: Vec<PgCast>pg_class: HashSet<PgClass>pg_collation: Vec<PgCollation>pg_constraint: Vec<PgConstraint>pg_conversion: Vec<PgConversion>pg_database: PgDatabasepg_db_role_setting: Vec<PgDbRoleSetting>pg_default_acl: Vec<PgDefaultAcl>pg_enum: HashSet<PgEnum>pg_event_trigger: Vec<PgEventTrigger>pg_extension: Vec<PgExtension>pg_foreign_data_wrapper: Vec<PgForeignDataWrapper>pg_foreign_server: Vec<PgForeignServer>pg_foreign_table: Vec<PgForeignTable>pg_index: Vec<PgIndex>pg_inherits: Vec<PgInherits>pg_language: HashSet<PgLanguage>pg_namespace: HashSet<PgNamespace>pg_opclass: Vec<PgOpclass>pg_operator: HashSet<PgOperator>pg_opfamily: Vec<PgOpfamily>pg_parameter_acl: Vec<PgParameterAcl>pg_partitioned_table: Vec<PgPartitionedTable>pg_policy: Vec<PgPolicy>pg_proc: HashSet<PgProc>pg_publication: HashSet<PgPublication>pg_publication_namespace: Vec<PgPublicationNamespace>pg_publication_rel: Vec<PgPublicationRel>pg_range: Vec<PgRange>pg_rules: Vec<PgRules>pg_views: Vec<PgViews>pg_matviews: Vec<PgMatviews>pg_sequence: Vec<PgSequence>pg_statistic_ext: Vec<PgStatisticExt>pg_subscription: Vec<PgSubscription>pg_transform: Vec<PgTransform>pg_trigger: Vec<PgTrigger>pg_ts_config: HashSet<PgTsConfig>pg_ts_config_map: Vec<PgTsConfigMap>pg_ts_dict: HashSet<PgTsDict>pg_ts_parser: Vec<PgTsParser>pg_ts_template: Vec<PgTsTemplate>pg_type: HashSet<PgType>pg_user_mappings: Vec<PgUserMappings>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for DbState
impl<'de> Deserialize<'de> for DbState
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DbState, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DbState, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for DbState
impl Serialize for DbState
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more