pub struct PgSubscription {Show 18 fields
pub subname: SmolStr,
pub subowner: SmolStr,
pub subenabled: bool,
pub subbinary: bool,
pub substream: PgSubscriptionSubstream,
pub subtwophasestate: PgSubscriptionSubtwophasestate,
pub subdisableonerr: bool,
pub subpasswordrequired: bool,
pub subrunasowner: bool,
pub subfailover: bool,
pub subconninfo: SmolStr,
pub subslotname: Option<SmolStr>,
pub subsynccommit: SmolStr,
pub subpublications: Vec<SmolStr>,
pub suborigin: Option<SmolStr>,
pub description: Option<SmolStr>,
pub seclabel: Option<SmolStr>,
pub seclabel_provider: Option<SmolStr>,
}Expand description
The DDL-only contents of pg_subscription
Fields
subname: SmolStrname Name of the subscription
subowner: SmolStroid (references pg_authid.oid) Owner of the subscription
subenabled: boolbool If true, the subscription is enabled and should be replicating
subbinary: boolbool If true, the subscription will request that the publisher send data in binary format
substream: PgSubscriptionSubstreamchar Controls how to handle the streaming of in-progress transactions: f = disallow streaming of in-progress transactions, t = spill the changes of in-progress transactions to disk and apply at once after the transaction is committed on the publisher and received by the subscriber, p = apply changes directly using a parallel apply worker if available (same as t if no worker is available)
subtwophasestate: PgSubscriptionSubtwophasestatechar State codes for two-phase mode: d = disabled, p = pending enablement, e = enabled
subdisableonerr: boolbool If true, the subscription will be disabled if one of its workers detects an error
subpasswordrequired: boolbool If true, the subscription will be required to specify a password for authentication
subrunasowner: boolbool If true, the subscription will be run with the permissions of the subscription owner
subfailover: boolbool If true, the associated replication slots (i.e. the main slot and the table sync slots) in the upstream database are enabled to be synchronized to the standbys
subconninfo: SmolStrtext Connection string to the upstream database
subslotname: Option<SmolStr>name Name of the replication slot in the upstream database (also used for the local replication origin name); null represents NONE
subsynccommit: SmolStrtext The synchronous_commit setting for the subscription’s workers to use
subpublications: Vec<SmolStr>text[] Array of subscribed publication names. These reference publications defined in the upstream database. For more on publications see Section 29.1.
suborigin: Option<SmolStr>text The origin value must be either none or any. The default is any. If none, the subscription will request the publisher to only send changes that don’t have an origin. If any, the publisher sends changes regardless of their origin.
description: Option<SmolStr>text The comment from pg_description
seclabel: Option<SmolStr>text The seclabel from pg_seclabel
seclabel_provider: Option<SmolStr>text The provider from pg_seclabel